@@ -18,6 +18,7 @@ import hashlib
 import http.client
 import io
 import os
+import sys
 
 import google.auth  # type: ignore
 import google.auth.transport.requests as tr_requests  # type: ignore
@@ -63,7 +64,11 @@ class CorruptingAuthorizedSession(tr_requests.AuthorizedSession):
             constructor.
     """
 
-    EMPTY_MD5 = base64.b64encode(hashlib.md5(b"").digest()).decode("utf-8")
+    EMPTY_MD5 = base64.b64encode(
+        hashlib.md5(
+            b"", **({"usedforsecurity": False} if sys.version_info >= (3, 9) else {})
+        ).digest()
+    ).decode("utf-8")
     crc32c = google_crc32c.Checksum()
     crc32c.update(b"")
     EMPTY_CRC32C = base64.b64encode(crc32c.digest()).decode("utf-8")
@@ -286,6 +291,23 @@ class TestDownload(object):
             assert self._read_response_content(response) == actual_contents
             check_tombstoned(download, authorized_transport)
 
+    @pytest.mark.parametrize("checksum", ["auto", "md5", "crc32c", None])
+    def test_single_shot_download_full(self, add_files, authorized_transport, checksum):
+        for info in ALL_FILES:
+            actual_contents = self._get_contents(info)
+            blob_name = get_blob_name(info)
+
+            # Create the actual download object.
+            media_url = utils.DOWNLOAD_URL_TEMPLATE.format(blob_name=blob_name)
+            download = self._make_one(
+                media_url, checksum=checksum, single_shot_download=True
+            )
+            # Consume the resource with single_shot_download enabled.
+            response = download.consume(authorized_transport)
+            assert response.status_code == http.client.OK
+            assert self._read_response_content(response) == actual_contents
+            check_tombstoned(download, authorized_transport)
+
     def test_download_to_stream(self, add_files, authorized_transport):
         for info in ALL_FILES:
             actual_contents = self._get_contents(info)
@@ -306,6 +328,31 @@ class TestDownload(object):
             assert stream.getvalue() == actual_contents
             check_tombstoned(download, authorized_transport)
 
+    @pytest.mark.parametrize("checksum", ["auto", "md5", "crc32c", None])
+    def test_single_shot_download_to_stream(
+        self, add_files, authorized_transport, checksum
+    ):
+        for info in ALL_FILES:
+            actual_contents = self._get_contents(info)
+            blob_name = get_blob_name(info)
+
+            # Create the actual download object.
+            media_url = utils.DOWNLOAD_URL_TEMPLATE.format(blob_name=blob_name)
+            stream = io.BytesIO()
+            download = self._make_one(
+                media_url, checksum=checksum, stream=stream, single_shot_download=True
+            )
+            # Consume the resource with single_shot_download enabled.
+            response = download.consume(authorized_transport)
+            assert response.status_code == http.client.OK
+            with pytest.raises(RuntimeError) as exc_info:
+                getattr(response, "content")
+            assert exc_info.value.args == (NO_BODY_ERR,)
+            assert response._content is False
+            assert response._content_consumed is True
+            assert stream.getvalue() == actual_contents
+            check_tombstoned(download, authorized_transport)
+
     def test_download_gzip_w_stored_content_headers(
         self, add_files, authorized_transport
     ):
